# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: course_lesson/grpc/course_lesson.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&course_lesson/grpc/course_lesson.proto\x12\x15\x64\x61rsman.course_lesson\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xa7\x01\n\x11\x41\x64\x64\x43ommentRequest\x12\x1d\n\x10owner_identifier\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\x12\x17\n\x0fuser_identifier\x18\x04 \x01(\t\x12\x17\n\nowner_slug\x18\x05 \x01(\tH\x01\x88\x01\x01\x42\x13\n\x11_owner_identifierB\r\n\x0b_owner_slug\"y\n\x12\x41\x64\x64\x43ommentResponse\x12\x14\n\x07message\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04\x63ode\x18\x02 \x01(\tH\x01\x88\x01\x01\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.StructB\n\n\x08_messageB\x07\n\x05_code\"w\n\x10\x43\x61tegoryResponse\x12\x14\n\x07message\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04\x63ode\x18\x02 \x01(\tH\x01\x88\x01\x01\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.StructB\n\n\x08_messageB\x07\n\x05_code\"g\n\x17\x43\x61tegoryRetrieveRequest\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x0c\n\x04slug\x18\x02 \x01(\t\x12\x19\n\x0cinvoker_unit\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x0f\n\r_invoker_unit\"\xe7\x01\n\x11\x43onsultantRequest\x12\x16\n\tfull_name\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x14\n\x0cphone_number\x18\x03 \x01(\t\x12\x16\n\titem_type\x18\x04 \x01(\tH\x01\x88\x01\x01\x12\x1c\n\x0fitem_identifier\x18\x05 \x01(\tH\x02\x88\x01\x01\x12#\n\x16preferred_contact_time\x18\x06 \x01(\tH\x03\x88\x01\x01\x42\x0c\n\n_full_nameB\x0c\n\n_item_typeB\x12\n\x10_item_identifierB\x19\n\x17_preferred_contact_time\"y\n\x12\x43onsultantResponse\x12\x14\n\x07message\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04\x63ode\x18\x02 \x01(\tH\x01\x88\x01\x01\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.StructB\n\n\x08_messageB\x07\n\x05_code\"[\n\x19\x43ourseBulkRetrieveRequest\x12\x12\n\nidentifier\x18\x01 \x03(\t\x12\x19\n\x0cinvoker_unit\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0f\n\r_invoker_unit\"\x9b\x01\n\x11\x43ourseListRequest\x12\x15\n\x08order_by\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x0bpage_number\x18\x02 \x01(\x05\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x16\n\titem_type\x18\x04 \x01(\tH\x01\x88\x01\x01\x12\x14\n\x0cinvoker_unit\x18\x05 \x01(\tB\x0b\n\t_order_byB\x0c\n\n_item_type\"u\n\x0e\x43ourseResponse\x12\x14\n\x07message\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04\x63ode\x18\x02 \x01(\tH\x01\x88\x01\x01\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.StructB\n\n\x08_messageB\x07\n\x05_code\"m\n\x1d\x43ourseRetrieveCommentsRequest\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x0c\n\x04slug\x18\x02 \x01(\t\x12\x19\n\x0cinvoker_unit\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x0f\n\r_invoker_unit\"j\n\x1a\x43ourseRetrieveRatesRequest\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x0c\n\x04slug\x18\x02 \x01(\t\x12\x19\n\x0cinvoker_unit\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x0f\n\r_invoker_unit\"e\n\x15\x43ourseRetrieveRequest\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x0c\n\x04slug\x18\x02 \x01(\t\x12\x19\n\x0cinvoker_unit\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x0f\n\r_invoker_unit\"v\n\x0fGeneralResponse\x12\x14\n\x07message\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04\x63ode\x18\x02 \x01(\tH\x01\x88\x01\x01\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.StructB\n\n\x08_messageB\x07\n\x05_code\"B\n\x16GeneralRetrieveRequest\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x14\n\x0cinvoker_unit\x18\x02 \x01(\t\",\n\x16InstallmentTermRequest\x12\x12\n\nidentifier\x18\x01 \x01(\t\"[\n\x19LessonBulkRetrieveRequest\x12\x12\n\nidentifier\x18\x01 \x03(\t\x12\x19\n\x0cinvoker_unit\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0f\n\r_invoker_unit\"\x8b\x01\n\x11LessonListRequest\x12\x15\n\x08order_by\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x0bpage_number\x18\x02 \x01(\x05\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x19\n\x0cinvoker_unit\x18\x04 \x01(\tH\x01\x88\x01\x01\x42\x0b\n\t_order_byB\x0f\n\r_invoker_unit\"u\n\x0eLessonResponse\x12\x14\n\x07message\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04\x63ode\x18\x02 \x01(\tH\x01\x88\x01\x01\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.StructB\n\n\x08_messageB\x07\n\x05_code\"m\n\x1dLessonRetrieveCommentsRequest\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x0c\n\x04slug\x18\x02 \x01(\t\x12\x19\n\x0cinvoker_unit\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x0f\n\r_invoker_unit\"e\n\x15LessonRetrieveRequest\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x0c\n\x04slug\x18\x02 \x01(\t\x12\x19\n\x0cinvoker_unit\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x0f\n\r_invoker_unit\"\x93\x01\n\x1fMasterCourseNotificationRequest\x12\x12\n\nfirst_name\x18\x01 \x01(\t\x12\x11\n\tlast_name\x18\x02 \x01(\t\x12\x14\n\x0cphone_number\x18\x03 \x01(\t\x12\x15\n\rmaster_course\x18\x04 \x01(\t\x12\x12\n\x05state\x18\x05 \x01(\x03H\x00\x88\x01\x01\x42\x08\n\x06_state\"T\n\"MasterCoursePreRegistrationRequest\x12\x15\n\rmaster_course\x18\x01 \x01(\t\x12\x17\n\x0fuser_identifier\x18\x02 \x01(\t\".\n\x18MasterCourseStateRequest\x12\x12\n\nidentifier\x18\x01 \x01(\t\"*\n\rMasterRequest\x12\x19\n\x11master_identifier\x18\x01 \x01(\t\"u\n\x0eMasterResponse\x12\x14\n\x07message\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04\x63ode\x18\x02 \x01(\tH\x01\x88\x01\x01\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.StructB\n\n\x08_messageB\x07\n\x05_code\"\x99\x01\n\x14NotificationResponse\x12\x14\n\x07message\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04\x63ode\x18\x02 \x01(\tH\x01\x88\x01\x01\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\x05state\x18\x04 \x01(\x03H\x02\x88\x01\x01\x42\n\n\x08_messageB\x07\n\x05_codeB\x08\n\x06_state\"\\\n\x1aPackageBulkRetrieveRequest\x12\x12\n\nidentifier\x18\x01 \x03(\t\x12\x19\n\x0cinvoker_unit\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0f\n\r_invoker_unit\"\x8c\x01\n\x12PackageListRequest\x12\x15\n\x08order_by\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x0bpage_number\x18\x02 \x01(\x05\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x19\n\x0cinvoker_unit\x18\x04 \x01(\tH\x01\x88\x01\x01\x42\x0b\n\t_order_byB\x0f\n\r_invoker_unit\"v\n\x0fPackageResponse\x12\x14\n\x07message\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04\x63ode\x18\x02 \x01(\tH\x01\x88\x01\x01\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.StructB\n\n\x08_messageB\x07\n\x05_code\"f\n\x16PackageRetrieveRequest\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x0c\n\x04slug\x18\x02 \x01(\t\x12\x19\n\x0cinvoker_unit\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x0f\n\r_invoker_unit\"~\n\x17PreRegistrationResponse\x12\x14\n\x07message\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04\x63ode\x18\x02 \x01(\tH\x01\x88\x01\x01\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.StructB\n\n\x08_messageB\x07\n\x05_code\"\x90\x01\n\x0bRateRequest\x12\x1d\n\x10owner_identifier\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x17\n\x0fuser_identifier\x18\x02 \x01(\t\x12\x0c\n\x04rate\x18\x03 \x01(\x02\x12\x17\n\nowner_slug\x18\x04 \x01(\tH\x01\x88\x01\x01\x42\x13\n\x11_owner_identifierB\r\n\x0b_owner_slug\"s\n\x0cRateResponse\x12\x14\n\x07message\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04\x63ode\x18\x02 \x01(\tH\x01\x88\x01\x01\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.StructB\n\n\x08_messageB\x07\n\x05_code\"o\n\x08Response\x12\x14\n\x07message\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04\x63ode\x18\x02 \x01(\tH\x01\x88\x01\x01\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.StructB\n\n\x08_messageB\x07\n\x05_code\"t\n\rStateResponse\x12\x14\n\x07message\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04\x63ode\x18\x02 \x01(\tH\x01\x88\x01\x01\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.StructB\n\n\x08_messageB\x07\n\x05_code\"x\n\x11TopBannerResponse\x12\x14\n\x07message\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04\x63ode\x18\x02 \x01(\tH\x01\x88\x01\x01\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.StructB\n\n\x08_messageB\x07\n\x05_code\"p\n\x12TriggerLikeRequest\x12\x1d\n\x10owner_identifier\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x17\n\nowner_slug\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x13\n\x11_owner_identifierB\r\n\x0b_owner_slug\"z\n\x13TriggerLikeResponse\x12\x14\n\x07message\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04\x63ode\x18\x02 \x01(\tH\x01\x88\x01\x01\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.StructB\n\n\x08_messageB\x07\n\x05_code2\xd2\x01\n\x12\x43\x61tegoryController\x12U\n\x10HierarchicalList\x12\x16.google.protobuf.Empty\x1a\'.darsman.course_lesson.CategoryResponse\"\x00\x12\x65\n\x08Retrieve\x12..darsman.course_lesson.CategoryRetrieveRequest\x1a\'.darsman.course_lesson.CategoryResponse\"\x00\x32w\n\x14\x43onsultantController\x12_\n\x06\x43reate\x12(.darsman.course_lesson.ConsultantRequest\x1a).darsman.course_lesson.ConsultantResponse\"\x00\x32\xf3\x07\n\x10\x43ourseController\x12\x63\n\x0c\x42ulkRetrieve\x12\x30.darsman.course_lesson.CourseBulkRetrieveRequest\x1a\x1f.darsman.course_lesson.Response\"\x00\x12`\n\x07\x43omment\x12(.darsman.course_lesson.AddCommentRequest\x1a).darsman.course_lesson.AddCommentResponse\"\x00\x12\x63\n\x12\x46\x65tchMasterCourses\x12$.darsman.course_lesson.MasterRequest\x1a%.darsman.course_lesson.MasterResponse\"\x00\x12_\n\x04Like\x12).darsman.course_lesson.TriggerLikeRequest\x1a*.darsman.course_lesson.TriggerLikeResponse\"\x00\x12Y\n\x04List\x12(.darsman.course_lesson.CourseListRequest\x1a%.darsman.course_lesson.CourseResponse\"\x00\x12Q\n\x04Rate\x12\".darsman.course_lesson.RateRequest\x1a#.darsman.course_lesson.RateResponse\"\x00\x12\x61\n\x08Retrieve\x12,.darsman.course_lesson.CourseRetrieveRequest\x1a%.darsman.course_lesson.CourseResponse\"\x00\x12q\n\x10RetrieveComments\x12\x34.darsman.course_lesson.CourseRetrieveCommentsRequest\x1a%.darsman.course_lesson.CourseResponse\"\x00\x12k\n\rRetrieveRates\x12\x31.darsman.course_lesson.CourseRetrieveRatesRequest\x1a%.darsman.course_lesson.CourseResponse\"\x00\x12\x61\n\x06UnLike\x12).darsman.course_lesson.TriggerLikeRequest\x1a*.darsman.course_lesson.TriggerLikeResponse\"\x00\x32\xf9\x07\n\x16\x45xpertCourseController\x12\x63\n\x0c\x42ulkRetrieve\x12\x30.darsman.course_lesson.CourseBulkRetrieveRequest\x1a\x1f.darsman.course_lesson.Response\"\x00\x12`\n\x07\x43omment\x12(.darsman.course_lesson.AddCommentRequest\x1a).darsman.course_lesson.AddCommentResponse\"\x00\x12\x63\n\x12\x46\x65tchMasterCourses\x12$.darsman.course_lesson.MasterRequest\x1a%.darsman.course_lesson.MasterResponse\"\x00\x12_\n\x04Like\x12).darsman.course_lesson.TriggerLikeRequest\x1a*.darsman.course_lesson.TriggerLikeResponse\"\x00\x12Y\n\x04List\x12(.darsman.course_lesson.CourseListRequest\x1a%.darsman.course_lesson.CourseResponse\"\x00\x12Q\n\x04Rate\x12\".darsman.course_lesson.RateRequest\x1a#.darsman.course_lesson.RateResponse\"\x00\x12\x61\n\x08Retrieve\x12,.darsman.course_lesson.CourseRetrieveRequest\x1a%.darsman.course_lesson.CourseResponse\"\x00\x12q\n\x10RetrieveComments\x12\x34.darsman.course_lesson.CourseRetrieveCommentsRequest\x1a%.darsman.course_lesson.CourseResponse\"\x00\x12k\n\rRetrieveRates\x12\x31.darsman.course_lesson.CourseRetrieveRatesRequest\x1a%.darsman.course_lesson.CourseResponse\"\x00\x12\x61\n\x06UnLike\x12).darsman.course_lesson.TriggerLikeRequest\x1a*.darsman.course_lesson.TriggerLikeResponse\"\x00\x32x\n\x11GeneralController\x12\x63\n\x08Retrieve\x12-.darsman.course_lesson.GeneralRetrieveRequest\x1a&.darsman.course_lesson.GeneralResponse\"\x00\x32\x8a\x04\n\x10LessonController\x12\x63\n\x0c\x42ulkRetrieve\x12\x30.darsman.course_lesson.LessonBulkRetrieveRequest\x1a\x1f.darsman.course_lesson.Response\"\x00\x12`\n\x07\x43omment\x12(.darsman.course_lesson.AddCommentRequest\x1a).darsman.course_lesson.AddCommentResponse\"\x00\x12Y\n\x04List\x12(.darsman.course_lesson.LessonListRequest\x1a%.darsman.course_lesson.LessonResponse\"\x00\x12\x61\n\x08Retrieve\x12,.darsman.course_lesson.LessonRetrieveRequest\x1a%.darsman.course_lesson.LessonResponse\"\x00\x12q\n\x10RetrieveComments\x12\x34.darsman.course_lesson.LessonRetrieveCommentsRequest\x1a%.darsman.course_lesson.LessonResponse\"\x00\x32\xd4\x0b\n\x16MasterCourseController\x12\x63\n\x0c\x42ulkRetrieve\x12\x30.darsman.course_lesson.CourseBulkRetrieveRequest\x1a\x1f.darsman.course_lesson.Response\"\x00\x12`\n\x07\x43omment\x12(.darsman.course_lesson.AddCommentRequest\x1a).darsman.course_lesson.AddCommentResponse\"\x00\x12{\n\x12\x43reateNotification\x12\x36.darsman.course_lesson.MasterCourseNotificationRequest\x1a+.darsman.course_lesson.NotificationResponse\"\x00\x12\x84\x01\n\x15\x43reatePreRegistration\x12\x39.darsman.course_lesson.MasterCoursePreRegistrationRequest\x1a..darsman.course_lesson.PreRegistrationResponse\"\x00\x12\x63\n\x12\x46\x65tchMasterCourses\x12$.darsman.course_lesson.MasterRequest\x1a%.darsman.course_lesson.MasterResponse\"\x00\x12_\n\x04Like\x12).darsman.course_lesson.TriggerLikeRequest\x1a*.darsman.course_lesson.TriggerLikeResponse\"\x00\x12Y\n\x04List\x12(.darsman.course_lesson.CourseListRequest\x1a%.darsman.course_lesson.CourseResponse\"\x00\x12Q\n\x04Rate\x12\".darsman.course_lesson.RateRequest\x1a#.darsman.course_lesson.RateResponse\"\x00\x12\x61\n\x08Retrieve\x12,.darsman.course_lesson.CourseRetrieveRequest\x1a%.darsman.course_lesson.CourseResponse\"\x00\x12q\n\x10RetrieveComments\x12\x34.darsman.course_lesson.CourseRetrieveCommentsRequest\x1a%.darsman.course_lesson.CourseResponse\"\x00\x12k\n\x17RetrieveInstallmentTerm\x12-.darsman.course_lesson.InstallmentTermRequest\x1a\x1f.darsman.course_lesson.Response\"\x00\x12k\n\rRetrieveRates\x12\x31.darsman.course_lesson.CourseRetrieveRatesRequest\x1a%.darsman.course_lesson.CourseResponse\"\x00\x12h\n\rRetrieveState\x12/.darsman.course_lesson.MasterCourseStateRequest\x1a$.darsman.course_lesson.StateResponse\"\x00\x12\x61\n\x06UnLike\x12).darsman.course_lesson.TriggerLikeRequest\x1a*.darsman.course_lesson.TriggerLikeResponse\"\x00\x32\xbb\x02\n\x11PackageController\x12\x64\n\x0c\x42ulkRetrieve\x12\x31.darsman.course_lesson.PackageBulkRetrieveRequest\x1a\x1f.darsman.course_lesson.Response\"\x00\x12[\n\x04List\x12).darsman.course_lesson.PackageListRequest\x1a&.darsman.course_lesson.PackageResponse\"\x00\x12\x63\n\x08Retrieve\x12-.darsman.course_lesson.PackageRetrieveRequest\x1a&.darsman.course_lesson.PackageResponse\"\x00\x32l\n\x13TopBannerController\x12U\n\x0fRetrieveCurrent\x12\x16.google.protobuf.Empty\x1a(.darsman.course_lesson.TopBannerResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'course_lesson.grpc.course_lesson_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ADDCOMMENTREQUEST']._serialized_start=125
  _globals['_ADDCOMMENTREQUEST']._serialized_end=292
  _globals['_ADDCOMMENTRESPONSE']._serialized_start=294
  _globals['_ADDCOMMENTRESPONSE']._serialized_end=415
  _globals['_CATEGORYRESPONSE']._serialized_start=417
  _globals['_CATEGORYRESPONSE']._serialized_end=536
  _globals['_CATEGORYRETRIEVEREQUEST']._serialized_start=538
  _globals['_CATEGORYRETRIEVEREQUEST']._serialized_end=641
  _globals['_CONSULTANTREQUEST']._serialized_start=644
  _globals['_CONSULTANTREQUEST']._serialized_end=875
  _globals['_CONSULTANTRESPONSE']._serialized_start=877
  _globals['_CONSULTANTRESPONSE']._serialized_end=998
  _globals['_COURSEBULKRETRIEVEREQUEST']._serialized_start=1000
  _globals['_COURSEBULKRETRIEVEREQUEST']._serialized_end=1091
  _globals['_COURSELISTREQUEST']._serialized_start=1094
  _globals['_COURSELISTREQUEST']._serialized_end=1249
  _globals['_COURSERESPONSE']._serialized_start=1251
  _globals['_COURSERESPONSE']._serialized_end=1368
  _globals['_COURSERETRIEVECOMMENTSREQUEST']._serialized_start=1370
  _globals['_COURSERETRIEVECOMMENTSREQUEST']._serialized_end=1479
  _globals['_COURSERETRIEVERATESREQUEST']._serialized_start=1481
  _globals['_COURSERETRIEVERATESREQUEST']._serialized_end=1587
  _globals['_COURSERETRIEVEREQUEST']._serialized_start=1589
  _globals['_COURSERETRIEVEREQUEST']._serialized_end=1690
  _globals['_GENERALRESPONSE']._serialized_start=1692
  _globals['_GENERALRESPONSE']._serialized_end=1810
  _globals['_GENERALRETRIEVEREQUEST']._serialized_start=1812
  _globals['_GENERALRETRIEVEREQUEST']._serialized_end=1878
  _globals['_INSTALLMENTTERMREQUEST']._serialized_start=1880
  _globals['_INSTALLMENTTERMREQUEST']._serialized_end=1924
  _globals['_LESSONBULKRETRIEVEREQUEST']._serialized_start=1926
  _globals['_LESSONBULKRETRIEVEREQUEST']._serialized_end=2017
  _globals['_LESSONLISTREQUEST']._serialized_start=2020
  _globals['_LESSONLISTREQUEST']._serialized_end=2159
  _globals['_LESSONRESPONSE']._serialized_start=2161
  _globals['_LESSONRESPONSE']._serialized_end=2278
  _globals['_LESSONRETRIEVECOMMENTSREQUEST']._serialized_start=2280
  _globals['_LESSONRETRIEVECOMMENTSREQUEST']._serialized_end=2389
  _globals['_LESSONRETRIEVEREQUEST']._serialized_start=2391
  _globals['_LESSONRETRIEVEREQUEST']._serialized_end=2492
  _globals['_MASTERCOURSENOTIFICATIONREQUEST']._serialized_start=2495
  _globals['_MASTERCOURSENOTIFICATIONREQUEST']._serialized_end=2642
  _globals['_MASTERCOURSEPREREGISTRATIONREQUEST']._serialized_start=2644
  _globals['_MASTERCOURSEPREREGISTRATIONREQUEST']._serialized_end=2728
  _globals['_MASTERCOURSESTATEREQUEST']._serialized_start=2730
  _globals['_MASTERCOURSESTATEREQUEST']._serialized_end=2776
  _globals['_MASTERREQUEST']._serialized_start=2778
  _globals['_MASTERREQUEST']._serialized_end=2820
  _globals['_MASTERRESPONSE']._serialized_start=2822
  _globals['_MASTERRESPONSE']._serialized_end=2939
  _globals['_NOTIFICATIONRESPONSE']._serialized_start=2942
  _globals['_NOTIFICATIONRESPONSE']._serialized_end=3095
  _globals['_PACKAGEBULKRETRIEVEREQUEST']._serialized_start=3097
  _globals['_PACKAGEBULKRETRIEVEREQUEST']._serialized_end=3189
  _globals['_PACKAGELISTREQUEST']._serialized_start=3192
  _globals['_PACKAGELISTREQUEST']._serialized_end=3332
  _globals['_PACKAGERESPONSE']._serialized_start=3334
  _globals['_PACKAGERESPONSE']._serialized_end=3452
  _globals['_PACKAGERETRIEVEREQUEST']._serialized_start=3454
  _globals['_PACKAGERETRIEVEREQUEST']._serialized_end=3556
  _globals['_PREREGISTRATIONRESPONSE']._serialized_start=3558
  _globals['_PREREGISTRATIONRESPONSE']._serialized_end=3684
  _globals['_RATEREQUEST']._serialized_start=3687
  _globals['_RATEREQUEST']._serialized_end=3831
  _globals['_RATERESPONSE']._serialized_start=3833
  _globals['_RATERESPONSE']._serialized_end=3948
  _globals['_RESPONSE']._serialized_start=3950
  _globals['_RESPONSE']._serialized_end=4061
  _globals['_STATERESPONSE']._serialized_start=4063
  _globals['_STATERESPONSE']._serialized_end=4179
  _globals['_TOPBANNERRESPONSE']._serialized_start=4181
  _globals['_TOPBANNERRESPONSE']._serialized_end=4301
  _globals['_TRIGGERLIKEREQUEST']._serialized_start=4303
  _globals['_TRIGGERLIKEREQUEST']._serialized_end=4415
  _globals['_TRIGGERLIKERESPONSE']._serialized_start=4417
  _globals['_TRIGGERLIKERESPONSE']._serialized_end=4539
  _globals['_CATEGORYCONTROLLER']._serialized_start=4542
  _globals['_CATEGORYCONTROLLER']._serialized_end=4752
  _globals['_CONSULTANTCONTROLLER']._serialized_start=4754
  _globals['_CONSULTANTCONTROLLER']._serialized_end=4873
  _globals['_COURSECONTROLLER']._serialized_start=4876
  _globals['_COURSECONTROLLER']._serialized_end=5887
  _globals['_EXPERTCOURSECONTROLLER']._serialized_start=5890
  _globals['_EXPERTCOURSECONTROLLER']._serialized_end=6907
  _globals['_GENERALCONTROLLER']._serialized_start=6909
  _globals['_GENERALCONTROLLER']._serialized_end=7029
  _globals['_LESSONCONTROLLER']._serialized_start=7032
  _globals['_LESSONCONTROLLER']._serialized_end=7554
  _globals['_MASTERCOURSECONTROLLER']._serialized_start=7557
  _globals['_MASTERCOURSECONTROLLER']._serialized_end=9049
  _globals['_PACKAGECONTROLLER']._serialized_start=9052
  _globals['_PACKAGECONTROLLER']._serialized_end=9367
  _globals['_TOPBANNERCONTROLLER']._serialized_start=9369
  _globals['_TOPBANNERCONTROLLER']._serialized_end=9477
# @@protoc_insertion_point(module_scope)
